from enum import Enum


class AbstractJobResultJobType(str, Enum):
    AUDIT_TRAIL_EXPORT = "AUDIT_TRAIL_EXPORT"
    IMPORT_LEGACY_PUBLISH_DATA = "IMPORT_LEGACY_PUBLISH_DATA"
    PROCESS_ARCHIVE = "PROCESS_ARCHIVE"
    PROCESS_BASIC_REPORT = "PROCESS_BASIC_REPORT"
    PROCESS_DOWNSAMPLING = "PROCESS_DOWNSAMPLING"
    PROCESS_EXPORT = "PROCESS_EXPORT"
    PROCESS_GROUP_EXPORT = "PROCESS_GROUP_EXPORT"
    PROCESS_IMPORT = "PROCESS_IMPORT"
    PROCESS_OFFLINE_IMPORT = "PROCESS_OFFLINE_IMPORT"
    PROCESS_UNARCHIVE = "PROCESS_UNARCHIVE"
    PUBLISH_DATA = "PUBLISH_DATA"
    REGRESSION_CALCULATION = "REGRESSION_CALCULATION"
    SAMPLING_OFFLINE_DATA_IMPORT = "SAMPLING_OFFLINE_DATA_IMPORT"
    SAMPLING_OFFLINE_DATA_IMPORT_AUTO = "SAMPLING_OFFLINE_DATA_IMPORT_AUTO"
    SAMPLING_RESCAN = "SAMPLING_RESCAN"

    def __str__(self) -> str:
        return str(self.value)
